Fix for inclusion of "arm_gemm" from src into "Types.h" from core

 - Added arm_compute::WeightFormat and converted to/from arm_gemm::WeightFormat
   when needed through two map function.
 - Moved to_string(WeightFormat) to TypePrinter.h

Resolves: COMPMID-5415
Signed-off-by: Ramy Elgammal <ramy.elgammal@arm.com>
Change-Id: I65f7942100bcd4dbf2c5cf6c07f26c8e1e3bf86e
Reviewed-on: https://eu-gerrit-1.euhpc.arm.com/c/VisualCompute/ComputeLibrary/+/438511
Tested-by: bsgcomp <bsgcomp@arm.com>
Reviewed-by: Pablo Tello <pablo.tello@arm.com>
Reviewed-by: Sicong Li <sicong.li@arm.com>
Comments-Addressed: bsgcomp <bsgcomp@arm.com>
Reviewed-on: https://review.mlplatform.org/c/ml/ComputeLibrary/+/7985
Tested-by: Arm Jenkins <bsgcomp@arm.com>
Comments-Addressed: Arm Jenkins <bsgcomp@arm.com>
Reviewed-by: Michalis Spyrou <michalis.spyrou@arm.com>
Benchmark: Arm Jenkins <bsgcomp@arm.com>
diff --git a/arm_compute/runtime/NEON/functions/NEGEMMConvolutionLayer.h b/arm_compute/runtime/NEON/functions/NEGEMMConvolutionLayer.h
index 2af11ad..a282662 100644
--- a/arm_compute/runtime/NEON/functions/NEGEMMConvolutionLayer.h
+++ b/arm_compute/runtime/NEON/functions/NEGEMMConvolutionLayer.h
@@ -131,7 +131,7 @@
      *
      * The user can query the database of optimised kernels in
      * arm_gemm by specifying one of the enumerations of
      * arm_gemm::WeightFormat in the weight_format field of the input
      * parameter weights_info. In case of success, the method
      * writes the expected format in the output parameter
      * expected_weight_format. The expected_weight_format can than be
@@ -140,7 +140,7 @@
      *
      * Use case one - query for a specific format:
      *
      *     WeightInfo weights_info(..., arm_gemm::WeightFormat::OHWIo4, ...); // Set the value of the input query.
      *     if (NEGEMMConvolutionlayer::has_opt_impl(WeightFormat(), ...., weights_info, ...))
      *     {
      *       auto conv = std::unique_ptr<NEGEMMConvolutionlayer>();
@@ -150,8 +150,8 @@
      *
      * Use case two - query for any format that would be optimal for the GEMM to execute:
      *
      *     WeightInfo weights_info(..., arm_gemm::WeightFormat::ANY, ...); // Set the value of the input query.
      *     arm_gemm::WeightFormat expected_wf;
      *     if (NEGEMMConvolutionlayer::has_opt_impl(expected_wf, ...., weights_info, ...))
      *     {
      *       auto conv = std::unique_ptr<NEGEMMConvolutionlayer>();
@@ -177,7 +177,7 @@
      *
      * @return a Status
      */
-    static Status has_opt_impl(arm_gemm::WeightFormat &expected_weight_format, const ITensorInfo *src, const ITensorInfo *weights, const ITensorInfo *biases, const ITensorInfo *dst,
+    static Status has_opt_impl(arm_compute::WeightFormat &expected_weight_format, const ITensorInfo *src, const ITensorInfo *weights, const ITensorInfo *biases, const ITensorInfo *dst,
                                const PadStrideInfo &conv_info,
                                const WeightsInfo &weights_info = WeightsInfo(), const Size2D &dilation = Size2D(1U, 1U), const ActivationLayerInfo &act_info = ActivationLayerInfo(),
                                bool enable_fast_math = false);
@@ -131,7 +131,7 @@
      * The user can query the database of optimised kernels in
      * arm_gemm by specifying one of the enumerations of
-     * arm_gemm::WeightFormat in the weight_format field of the input
+     * arm_compute::WeightFormat in the weight_format field of the input
      * parameter weights_info. In case of success, the method
      * writes the expected format in the output parameter
@@ -140,7 +140,7 @@
      * Use case one - query for a specific format:
      *
-     *     WeightInfo weights_info(..., arm_gemm::WeightFormat::OHWIo4, ...); // Set the value of the input query.
+     *     WeightInfo weights_info(..., arm_compute::WeightFormat::OHWIo4, ...); // Set the value of the input query.
      *     if (NEGEMMConvolutionlayer::has_opt_impl(WeightFormat(), ...., weights_info, ...))
      *     {
@@ -150,8 +150,8 @@
      * Use case two - query for any format that would be optimal for the GEMM to execute:
      *
-     *     WeightInfo weights_info(..., arm_gemm::WeightFormat::ANY, ...); // Set the value of the input query.
-     *     arm_gemm::WeightFormat expected_wf;
+     *     WeightInfo weights_info(..., arm_compute::WeightFormat::ANY, ...); // Set the value of the input query.
+     *     arm_compute::WeightFormat expected_wf;
      *     if (NEGEMMConvolutionlayer::has_opt_impl(expected_wf, ...., weights_info, ...))
      *     {